/*
 * Copyright (C) 2008 Kikini Limited and contributors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.kikini.util.cmdline;

import java.lang.reflect.Type;

/**
 * Thrown when a command-line argument specifies an invalid (or illegal) value
 * for a parameter.
 * 
 * @author Jon Vincent
 */
public class ArgumentFormatException extends UnrecognizedArgumentException {

    private static final long serialVersionUID = 1038354255346374689L;

    private final String value;
    private final Type type;

    /** Creates a new instance. */
    public ArgumentFormatException(String message, String arg, String value, Type type, Throwable cause) {
        super(message, arg, cause);

        if (type == null) throw new NullPointerException();
        this.value = value;
        this.type = type;
    }

    static ArgumentFormatException forMissingValue(String arg, Type type) {
        String format = "Invalid parameter: %s (must specify %s value)";
        return new ArgumentFormatException(String.format(format, arg, type), arg, null, type, null);
    }

    static ArgumentFormatException forInvalidValue(String arg, String value, Type type, Throwable cause) {
        String format = "Invalid parameter: %s (\"%s\" is not %s value)";
        return new ArgumentFormatException(String.format(format, arg, value, type), arg, value, type, cause);
    }

    /**
     * Returns the parameter value specified on the command line, or {@code
     * null} if it was missing.
     */
    public String getValue() {
        return value;
    }

    /** Returns the name of the variable type. */
    public String getType() {
        return type.toString();
    }

}