/*
 * Copyright (C) 2008 Kikini Limited and contributors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.kikini.util.cmdline;

/**
 * Thrown when a required command-line argument is not set.
 * 
 * @author Jon Vincent
 */
public class MissingArgumentException extends Exception {

    private static final long serialVersionUID = -2438882588091966992L;

    private final String name;

    /** Creates a new instance. */
    public MissingArgumentException(String message, String name) {
        super(message);
        this.name = name;
    }

    static MissingArgumentException forTarget(String name) {
        String message = "Missing parameter: must specify " + (name.length() != 0 ? name : "target");
        return new MissingArgumentException(message, (name.length() != 0 ? name : null));
    }

    /**
     * Returns the name of the missing argument, or null if it is the "nameless"
     * argument.
     */
    public String getName() {
        return name;
    }

}