/*
 * Copyright (C) 2008 Kikini Limited and contributors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.kikini.util.cmdline;

/**
 * Thrown when an error occurs while applying a set of command-line arguments.
 * 
 * @author Jon Vincent
 */
public class UnrecognizedArgumentException extends Exception {

    private static final long serialVersionUID = -8648557400716461126L;

    private final String arg;

    /** Creates a new instance. */
    public UnrecognizedArgumentException(String message, String arg, Throwable cause) {
        super(message, cause);
        this.arg = arg;
    }

    static UnrecognizedArgumentException forArgument(String arg) {
        String format = "Unrecognized parameter: %s";
        return new UnrecognizedArgumentException(String.format(format, arg), arg, null);
    }

    /** Returns the entire argument text, as specified on the command line. */
    public String getArgument() {
        return arg;
    }

}